import requests
import base64
from .config import LF_ENDPOINT




class AgentForce:
    def __init__(self,latent_force_api_key):
        
        self.backend_url=LF_ENDPOINT
        self.latent_force_api_key=latent_force_api_key
   
    def load_and_process_image(self,image_path):

        with open(image_path, 'rb') as image_file:
                image = image_file.read()

        encoded_image = base64.b64encode(image).decode('utf-8')

        return encoded_image
         

    def agent_force_model_results(self, data):

            headers = {
                "Content-Type": "application/json",
                "Accept": "application/json"
            }

            url = f"{self.backend_url}/api/get-agent-predictions"
            response = requests.post(url, json=data, headers=headers,timeout=100)
            if response.status_code == 200:
                return response.json()
            else:
                return {"error": f"Failed to get prediction. Status Code: {response.status_code}"}


    def process(self, model_name,agent_inputs=None):
        if model_name is None:
            return "No Model name  ! "
        if agent_inputs is None:
                return "No agent inputs ! "
             
        self.api_key=self.latent_force_api_key
        self.model_name=model_name
        self.agent_inputs=agent_inputs
        data = {
            "api_key": self.latent_force_api_key,
            "model_name": self.model_name,
            "agent_inputs":self.agent_inputs,
                }
 
        response=self.agent_force_model_results(data)
   

        return response






from openai import OpenAI as oi
from .modelforce import ModelForce
from datetime import datetime
from .config import LF_ENDPOINT
class OpenAI:
    def __init__(self, api_key,latent_force_api_key,project_name):
        
        self.client = oi(api_key=api_key)
        self.latent_force_api_key=latent_force_api_key
        self.project_name=project_name
        self.model_force_instance = ModelForce(self.latent_force_api_key, self.project_name)

    def chat_completions(self, model_name,messages,lora_id=None):
       
        self.llm_input=None
        self.llm_output=None
        self.promt=None
        self.api_key=self.latent_force_api_key
        self.project_name=self.project_name
        self.message=messages
        self.model_name=model_name
        self.lora_id=lora_id


        answer=None
        return_response=None
        if model_name.startswith("latentforce/"):
            self.model_name=model_name[len("latentforce/"):]
            data={
                "model_name":self.model_name,
                "model_inputs":self.message,
                "project_name":self.project_name,
                "api_key": self.api_key
            }
            if self.lora_id is not None:
                data["lora_id"] = self.lora_id
            response=self.model_force_instance.latent_force_model_results(data)
            answer=response
            return_response=response
        else:

            response = self.client.chat.completions.create(
                model= self.model_name,
                messages=messages
                
            )
            return_response=response
            answer=response
            

        self.llm_output=answer
   
        data = {
            "api_key": self.latent_force_api_key,
            "project_name": self.project_name,
            "model_name": self.model_name,
            "messages":self.message,
            "output":self.llm_output,
            "score" : None
                }
        self.model_force_instance.log_llm_v1(data)
        return return_response




import requests
from .config import LF_ENDPOINT



import base64
import io

class ModelForce:
    def __init__(self, api_key, project_name):
        self.api_key = api_key
        self.project_name = project_name
        # self.backend_url = "http://app.latentforce.ai/log"  # URL of your Flask app logging endpoint
        self.backend_url = LF_ENDPOINT  # URL of your Flask app logging endpoint


    def log_llm_v1(self, data):

        response = requests.post(f"{self.backend_url}/api/log_llm_v1", json=data)

        
        if response.status_code == 200:
            print("Logged Successfully..")
        else:
            error_message = response.json().get('error', 'No error message provided')
            print(f"Error: {error_message}. The data is not Logged ")
            
    def latent_force_model_results(self, data):

            headers = {
                "Content-Type": "application/json",
                "Accept": "application/json"
            }
            url = f"{self.backend_url}/api/model_predict"
            response = requests.post(url, json=data, headers=headers,timeout=100)
            if response.status_code == 200:
                return response.json()
            else:
                return {"error": f"Failed to get prediction. Status Code: {response.status_code}"}

